//
// C++ Interface: showheaderdialog
//
// Description:
//
//
// Author: Ulrich Weigelt <ulrich.weigelt@gmx.de>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef SHOWHEADERDIALOG_H
#define SHOWHEADERDIALOG_H

//QT headers
#include <tqlayout.h>
#include <tqlabel.h>

//KDE headers
#include <kdialogbase.h>
#include <tdelocale.h>
#include <klineedit.h>
#include <ktextedit.h>

//KShowmail headers
#include "constants.h"

/**
 * Used in ShowRecordElem to show the mail header.
 *
 * @author Ulrich Weigelt <ulrich.weigelt@gmx.de>
 */
class ShowHeaderDialog : public KDialogBase
{
Q_OBJECT

  public:
    /**
     * Generic constructor.
     * @param parent parent of the dialog
     * @param caption the dialog caption
     * @param subject mail subject
     * @param header mail header
     */
    ShowHeaderDialog( TQWidget* parent, TQString& caption, TQString& subject, TQString header );

    /**
     * Destructor
     */
    ~ShowHeaderDialog();
};

#endif
